#!/bin/sh
# 08/06/2003

# TODO:- Doesn't build 'ul' and 'setterm' - claims lack of ncurses
# TODO:- Doesn't build (?) - genuine lack of termcap

[ "${SYSCONF}" ] && . ${SYSCONF}
[ "${PKGFILE}" ] && . ${PKGFILE}

make_build()
{
# CONFIGURE...
# ...back up MCONFIG first
	[ -r MCONFIG.old ] || cp MCONFIG MCONFIG.old
# ...correct assumption _FILE_OFFSET_BITS=64 (not always with uClibc)
	grep -v _FILE_OFFSET_BITS MCONFIG.old > MCONFIG

	PATH=${TCTREE}/usr/${TARGET_CPU}-linux-uclibc/bin:${PATH} \
	 CC=${TARGET_CPU}-uclibc-gcc \
		./configure --prefix=/ \
		 --host=`uname -m` --target=${TARGET_CPU} --build=${TARGET_CPU} \
		 --disable-nls --disable-largefile \
		 || exit 1

# BUILD...
# ...some cross-compilation doesn't work, eg. subdirectory 'mount'
# fails; 'mkminix-0.1' and 'rescuept' don't appear to contain
# programs; 'partx' doesn't respect the 'configure' settings.

	SUBFAIL=n
	for SUBDIR in disk-utils fdisk hwclock login-utils misc-utils sys-utils text-utils ; do \
		( cd ${SUBDIR} && \
		PATH=${TCTREE}/usr/${TARGET_CPU}-linux-uclibc/bin:${PATH} make \
		) || SUBFAIL=y ;\
	done
	[ ${SUBFAIL} = 'y' ] && exit 1

# INSTALL...

	( cd disk-utils && make DESTDIR=${DISKUTILS_INSTTEMP} install ) || exit 1

	mkdir -p ${FDISK_INSTTEMP}/usr/share/man/man8
	( cd fdisk && make DESTDIR=${FDISK_INSTTEMP} install ) || exit 1

	mkdir -p ${REMAINDER_INSTTEMP}/usr/share/man/man8
	SUBFAIL=n
	for SUBDIR in hwclock login-utils misc-utils sys-utils text-utils ; do \
		( cd ${SUBDIR} && \
		make USE_TTY_GROUP=no DESTDIR=${REMAINDER_INSTTEMP} install \
		) || SUBFAIL=y ;\
	done
	[ ${SUBFAIL} = 'y' ] && exit 1
	true
}

make_tc_host()
{
	[ -r MCONFIG.old ] || cp MCONFIG MCONFIG.old
#	strip out the _FILE_OFFSET_BITS=64 assumption (since we
#	use 32 ...and the compiler might complain otherwise)
	grep -v _FILE_OFFSET_BITS MCONFIG.old > MCONFIG

	./configure --prefix=${INSTTEMP}/usr || exit 1
#
#	# full `make` fails -- on "mount" (which busybox provides)
#	PATH=${TCTREE}/usr/${TARGET_CPU}-linux-uclibc/bin:${PATH} make
#	# disk-utils gives us fdformat/fdformat.8
	( cd disk-utils && make ) || exit 1
#	# fdisk and sfdisk:
	( cd fdisk && make ) || exit 1
##	# login-utils gives us agetty/passwd/passwd.1
#	( cd login-utils && PATH=${TCTREE}/usr/${TARGET_CPU}-linux-uclibc/bin:${PATH} make ) || exit 1
##	# misc-utils
	( cd misc-utils && make ) || exit 1
##	# sys-utils gives us rdev: (but doesn't work)
#	( cd sys-utils && PATH=${TCTREE}/usr/${TARGET_CPU}-linux-uclibc/bin:${PATH} make ) || exit 1
#
#	# since we omit a full `make`, don't full `install`?
#	make PREFIX=${SOMETREE} install
	mkdir -p ${INSTTEMP}/usr/bin 
	mkdir -p ${INSTTEMP}/usr/man/man8
	( cd disk-utils && cp fdformat ${INSTTEMP}/usr/bin/ && cp fdformat.8 ${INSTTEMP}/usr/man/man8/ ) || exit 1
	( cd fdisk && make SBINDIR=${INSTTEMP}/sbin MAN8DIR=${INSTTEMP}/usr/man/man8 install ) || exit 1
	# misc-utils wants to chgrp, and not to fail :(
	( cd misc-utils && cp whereis ${INSTTEMP}/usr/bin && cp whereis.1 ${INSTTEMP}/usr/man/man1/ ) || exit 1
# SBINDIR=${INSTTEMP}/sbin MAN8DIR=${INSTTEMP}/usr/man/man8 install ) || exit 1
}

case "$1" in
distro-cross)
	make_build || exit 1
	;;
toolchain-host)
	INSTTEMP=${TCTREE} make_tc_host || exit 1
	;;
*)
	exit 1
	;;
esac
